========================================================================
django-only-staff - Middleware for only allowing access to staff members
========================================================================

Version |release|

Usage
=====

- Install the module using ``pip install django-only-staff``
- Add ``only_staff.middleware.only_staff`` to ``MIDDLEWARE``

- `Github <https://github.com/matthiask/django-only-staff/>`_
